(v0.12.8)=
### 0.12.8 {small}`2026-01-27`

#### Bug fixes

- Actually copy single zarr store input in {func}`anndata.experimental.concat_on_disk` {user}`ilan-gold` ({pr}`2267`)
- Fix `compressor` kwarg handling when writing to zarr v3 {user}`ilan-gold` ({pr}`2270`)
- Only open HDF5 file once in backed mode {user}`flying-sheep` ({pr}`2274`)
- Fix {obj}`numpy.uint` support in {func}`anndata.experimental.read_lazy` and {func}`anndata.experimental.read_elem_lazy` {user}`flying-sheep` ({pr}`2287`)
- `var` index is loaded into memory if it wasn't previously for {func}`anndata.concat` when {attr}`anndata.AnnData.var` is a {class}`anndata.experimental.backed.Dataset2D` {user}`ilan-gold` ({pr}`2299`)
